@@ -107,7 +107,7 @@ static MicrofeedError* update_feed(MicrofeedFeed* feed, int user_initiated, void
 				}
 			}
 			microfeed_feed_iterator_free(iterator);
-		} else {
+		} else if (!(error = check_if_error(json))) {
 			error = microfeed_error_new(MICROFEED_ERROR_COMMUNICATION_FAILED, "Invalid reply (expected JSON array).");
 		}
 		microfeed_json_free(json);
